import { createContext, useCallback, useContext, useEffect, useState } from "react";
import { isNil } from "../../shared";
import { supportsMatchMedia } from "./useMediaQuery";
import { useDebouncedCallback } from "use-debounce";
/* eslint-disable sort-keys-fix/sort-keys-fix */

import { jsx as _jsx } from "react/jsx-runtime";
export const Breakpoints = {
  md: "(max-width: 900px)",
  lg: "(min-width: 901px)"
};
/* eslint-enable sort-keys-fix/sort-keys-fix */

export const BreakpointContext = /*#__PURE__*/createContext({});
export function BreakpointProvider({
  children,
  defaultBreakpoint = "lg"
}) {
  const getCurrentBreakpoint = useCallback(() => {
    if (supportsMatchMedia) {
      for (const [key, value] of Object.entries(Breakpoints)) {
        if (window.matchMedia(value).matches) {
          return key;
        }
      }
    }

    return defaultBreakpoint;
  }, [defaultBreakpoint]);
  const [breakpoint, setBreakpoint] = useState(getCurrentBreakpoint);
  const handleResize = useDebouncedCallback(() => {
    setBreakpoint(getCurrentBreakpoint());
  }, 50);
  useEffect(() => {
    window.addEventListener("resize", handleResize);
    return () => {
      window.removeEventListener("resize", handleResize);
    };
  }, [handleResize]);
  return /*#__PURE__*/_jsx(BreakpointContext.Provider, {
    value: {
      breakpoint
    },
    children: children
  });
}
export function useBreakpointContext() {
  return useContext(BreakpointContext);
}
export function useBreakpoint() {
  const context = useContext(BreakpointContext);
  return !isNil(context) ? context.breakpoint : undefined;
}